# coding: utf-8

"""
    CardPay REST API

    Welcome to the CardPay REST API. The CardPay API uses HTTP verbs and a REST resources endpoint structure (see more info about REST). Request and response payloads are formatted as JSON. Merchant uses API to create payments, refunds, payouts or recurrings, check or update transaction status and get information about created transactions. In API authentication process based on OAuth 2.0 standard. For recent changes see changelog section.  # noqa: E501

    OpenAPI spec version: 3.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from cardpay.model.plan import Plan  # noqa: F401,E501
from cardpay.model.recurring_request_filing import RecurringRequestFiling  # noqa: F401,E501


class RecurringRequestRecurringData(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'amount': 'float',
        'begin': 'bool',
        'currency': 'str',
        'dynamic_descriptor': 'str',
        'filing': 'RecurringRequestFiling',
        'generate_token': 'bool',
        'initiator': 'str',
        'interval': 'int',
        'note': 'str',
        'payments': 'int',
        'period': 'str',
        'plan': 'Plan',
        'preauth': 'bool',
        'retries': 'int',
        'subscription_start': 'datetime'
    }

    attribute_map = {
        'amount': 'amount',
        'begin': 'begin',
        'currency': 'currency',
        'dynamic_descriptor': 'dynamic_descriptor',
        'filing': 'filing',
        'generate_token': 'generate_token',
        'initiator': 'initiator',
        'interval': 'interval',
        'note': 'note',
        'payments': 'payments',
        'period': 'period',
        'plan': 'plan',
        'preauth': 'preauth',
        'retries': 'retries',
        'subscription_start': 'subscription_start'
    }

    def __init__(self, amount=None, begin=None, currency=None, dynamic_descriptor=None, filing=None, generate_token=None, initiator=None, interval=None, note=None, payments=None, period=None, plan=None, preauth=None, retries=None, subscription_start=None):  # noqa: E501
        """RecurringRequestRecurringData - a model defined in Swagger"""  # noqa: E501

        self._amount = None
        self._begin = None
        self._currency = None
        self._dynamic_descriptor = None
        self._filing = None
        self._generate_token = None
        self._initiator = None
        self._interval = None
        self._note = None
        self._payments = None
        self._period = None
        self._plan = None
        self._preauth = None
        self._retries = None
        self._subscription_start = None
        self.discriminator = None

        if amount is not None:
            self.amount = amount
        if begin is not None:
            self.begin = begin
        if currency is not None:
            self.currency = currency
        if dynamic_descriptor is not None:
            self.dynamic_descriptor = dynamic_descriptor
        if filing is not None:
            self.filing = filing
        if generate_token is not None:
            self.generate_token = generate_token
        if initiator is not None:
            self.initiator = initiator
        if interval is not None:
            self.interval = interval
        if note is not None:
            self.note = note
        if payments is not None:
            self.payments = payments
        if period is not None:
            self.period = period
        if plan is not None:
            self.plan = plan
        if preauth is not None:
            self.preauth = preauth
        if retries is not None:
            self.retries = retries
        if subscription_start is not None:
            self.subscription_start = subscription_start

    @property
    def amount(self):
        """Gets the amount of this RecurringRequestRecurringData.  # noqa: E501

        The total transaction amount in selected currency with dot as a decimal separator, must be less than 100 millions  # noqa: E501

        :return: The amount of this RecurringRequestRecurringData.  # noqa: E501
        :rtype: float
        """
        return self._amount

    @amount.setter
    def amount(self, amount):
        """Sets the amount of this RecurringRequestRecurringData.

        The total transaction amount in selected currency with dot as a decimal separator, must be less than 100 millions  # noqa: E501

        :param amount: The amount of this RecurringRequestRecurringData.  # noqa: E501
        :type: float
        """

        self._amount = amount

    @property
    def begin(self):
        """Gets the begin of this RecurringRequestRecurringData.  # noqa: E501


        :return: The begin of this RecurringRequestRecurringData.  # noqa: E501
        :rtype: bool
        """
        return self._begin

    @begin.setter
    def begin(self, begin):
        """Sets the begin of this RecurringRequestRecurringData.


        :param begin: The begin of this RecurringRequestRecurringData.  # noqa: E501
        :type: bool
        """

        self._begin = begin

    @property
    def currency(self):
        """Gets the currency of this RecurringRequestRecurringData.  # noqa: E501

        [ISO 4217](https://en.wikipedia.org/wiki/ISO_4217) currency code  # noqa: E501

        :return: The currency of this RecurringRequestRecurringData.  # noqa: E501
        :rtype: str
        """
        return self._currency

    @currency.setter
    def currency(self, currency):
        """Sets the currency of this RecurringRequestRecurringData.

        [ISO 4217](https://en.wikipedia.org/wiki/ISO_4217) currency code  # noqa: E501

        :param currency: The currency of this RecurringRequestRecurringData.  # noqa: E501
        :type: str
        """

        self._currency = currency

    @property
    def dynamic_descriptor(self):
        """Gets the dynamic_descriptor of this RecurringRequestRecurringData.  # noqa: E501

        Short description of the service or product, must be enabled by CardPay manager to be used  # noqa: E501

        :return: The dynamic_descriptor of this RecurringRequestRecurringData.  # noqa: E501
        :rtype: str
        """
        return self._dynamic_descriptor

    @dynamic_descriptor.setter
    def dynamic_descriptor(self, dynamic_descriptor):
        """Sets the dynamic_descriptor of this RecurringRequestRecurringData.

        Short description of the service or product, must be enabled by CardPay manager to be used  # noqa: E501

        :param dynamic_descriptor: The dynamic_descriptor of this RecurringRequestRecurringData.  # noqa: E501
        :type: str
        """
        if dynamic_descriptor is not None and len(dynamic_descriptor) > 25:
            raise ValueError("Invalid value for `dynamic_descriptor`, length must be less than or equal to `25`")  # noqa: E501
        if dynamic_descriptor is not None and len(dynamic_descriptor) < 0:
            raise ValueError("Invalid value for `dynamic_descriptor`, length must be greater than or equal to `0`")  # noqa: E501

        self._dynamic_descriptor = dynamic_descriptor

    @property
    def filing(self):
        """Gets the filing of this RecurringRequestRecurringData.  # noqa: E501

        Filing data, should be send in all recurring requests besides first recurring request First recurring request should be send without filing attribute  # noqa: E501

        :return: The filing of this RecurringRequestRecurringData.  # noqa: E501
        :rtype: RecurringRequestFiling
        """
        return self._filing

    @filing.setter
    def filing(self, filing):
        """Sets the filing of this RecurringRequestRecurringData.

        Filing data, should be send in all recurring requests besides first recurring request First recurring request should be send without filing attribute  # noqa: E501

        :param filing: The filing of this RecurringRequestRecurringData.  # noqa: E501
        :type: RecurringRequestFiling
        """

        self._filing = filing

    @property
    def generate_token(self):
        """Gets the generate_token of this RecurringRequestRecurringData.  # noqa: E501

        If set to `true`, token will be generated and returned in the response  # noqa: E501

        :return: The generate_token of this RecurringRequestRecurringData.  # noqa: E501
        :rtype: bool
        """
        return self._generate_token

    @generate_token.setter
    def generate_token(self, generate_token):
        """Sets the generate_token of this RecurringRequestRecurringData.

        If set to `true`, token will be generated and returned in the response  # noqa: E501

        :param generate_token: The generate_token of this RecurringRequestRecurringData.  # noqa: E501
        :type: bool
        """

        self._generate_token = generate_token

    @property
    def initiator(self):
        """Gets the initiator of this RecurringRequestRecurringData.  # noqa: E501

        Can be only 2 values: `mit` (merchant initiated transaction), `cit` (cardholder initiated transaction)  # noqa: E501

        :return: The initiator of this RecurringRequestRecurringData.  # noqa: E501
        :rtype: str
        """
        return self._initiator

    @initiator.setter
    def initiator(self, initiator):
        """Sets the initiator of this RecurringRequestRecurringData.

        Can be only 2 values: `mit` (merchant initiated transaction), `cit` (cardholder initiated transaction)  # noqa: E501

        :param initiator: The initiator of this RecurringRequestRecurringData.  # noqa: E501
        :type: str
        """
        if initiator is not None and not re.search(r'mit|cit', initiator):  # noqa: E501
            raise ValueError(r"Invalid value for `initiator`, must be a follow pattern or equal to `/mit|cit/`")  # noqa: E501

        self._initiator = initiator

    @property
    def interval(self):
        """Gets the interval of this RecurringRequestRecurringData.  # noqa: E501

        Frequency interval of period, can be 1-365 depending on selected period value. Minimum value of period + interval can be 7 days / 1 week. Maximum value of period + interval plan can be 365 days / 52 weeks / 12 months / 1 year. 1-60 minutes - for **sandbox environment** and testing purpose only.  # noqa: E501

        :return: The interval of this RecurringRequestRecurringData.  # noqa: E501
        :rtype: int
        """
        return self._interval

    @interval.setter
    def interval(self, interval):
        """Sets the interval of this RecurringRequestRecurringData.

        Frequency interval of period, can be 1-365 depending on selected period value. Minimum value of period + interval can be 7 days / 1 week. Maximum value of period + interval plan can be 365 days / 52 weeks / 12 months / 1 year. 1-60 minutes - for **sandbox environment** and testing purpose only.  # noqa: E501

        :param interval: The interval of this RecurringRequestRecurringData.  # noqa: E501
        :type: int
        """
        if interval is not None and interval < 1:  # noqa: E501
            raise ValueError("Invalid value for `interval`, must be a value greater than or equal to `1`")  # noqa: E501

        self._interval = interval

    @property
    def note(self):
        """Gets the note of this RecurringRequestRecurringData.  # noqa: E501

        Note about the transaction that will not be displayed to customer  # noqa: E501

        :return: The note of this RecurringRequestRecurringData.  # noqa: E501
        :rtype: str
        """
        return self._note

    @note.setter
    def note(self, note):
        """Sets the note of this RecurringRequestRecurringData.

        Note about the transaction that will not be displayed to customer  # noqa: E501

        :param note: The note of this RecurringRequestRecurringData.  # noqa: E501
        :type: str
        """
        if note is not None and len(note) > 100:
            raise ValueError("Invalid value for `note`, length must be less than or equal to `100`")  # noqa: E501
        if note is not None and len(note) < 0:
            raise ValueError("Invalid value for `note`, length must be greater than or equal to `0`")  # noqa: E501

        self._note = note

    @property
    def payments(self):
        """Gets the payments of this RecurringRequestRecurringData.  # noqa: E501

        Number of total payments to be charged per defined interval, can be 2-200.  # noqa: E501

        :return: The payments of this RecurringRequestRecurringData.  # noqa: E501
        :rtype: int
        """
        return self._payments

    @payments.setter
    def payments(self, payments):
        """Sets the payments of this RecurringRequestRecurringData.

        Number of total payments to be charged per defined interval, can be 2-200.  # noqa: E501

        :param payments: The payments of this RecurringRequestRecurringData.  # noqa: E501
        :type: int
        """
        if payments is not None and payments > 200:  # noqa: E501
            raise ValueError("Invalid value for `payments`, must be a value less than or equal to `200`")  # noqa: E501
        if payments is not None and payments < 2:  # noqa: E501
            raise ValueError("Invalid value for `payments`, must be a value greater than or equal to `2`")  # noqa: E501

        self._payments = payments

    class Period(object):
        MINUTE = "minute"
        DAY = "day"
        WEEK = "week"
        MONTH = "month"
        YEAR = "year"
        

    @property
    def period(self):
        """Gets the period of this RecurringRequestRecurringData.  # noqa: E501

        Initial period of recurring, can be `day`, `week`, `month`, `year`.  `minute` - for **sandbox environment** and testing purpose only.  # noqa: E501

        :return: The period of this RecurringRequestRecurringData.  # noqa: E501
        :rtype: str
        """
        return self._period

    @period.setter
    def period(self, period):
        """Sets the period of this RecurringRequestRecurringData.

        Initial period of recurring, can be `day`, `week`, `month`, `year`.  `minute` - for **sandbox environment** and testing purpose only.  # noqa: E501

        :param period: The period of this RecurringRequestRecurringData.  # noqa: E501
        :type: str
        """
        allowed_values = ["minute", "day", "week", "month", "year"]  # noqa: E501
        if period not in allowed_values:
            raise ValueError(
                "Invalid value for `period` ({0}), must be one of {1}"  # noqa: E501
                .format(period, allowed_values)
            )

        self._period = period

    @property
    def plan(self):
        """Gets the plan of this RecurringRequestRecurringData.  # noqa: E501

        Plan data  # noqa: E501

        :return: The plan of this RecurringRequestRecurringData.  # noqa: E501
        :rtype: Plan
        """
        return self._plan

    @plan.setter
    def plan(self, plan):
        """Sets the plan of this RecurringRequestRecurringData.

        Plan data  # noqa: E501

        :param plan: The plan of this RecurringRequestRecurringData.  # noqa: E501
        :type: Plan
        """

        self._plan = plan

    @property
    def preauth(self):
        """Gets the preauth of this RecurringRequestRecurringData.  # noqa: E501

        This parameter is allowed to be used only for first recurring payment. If set to `true`, the amount will not be captured but only blocked *(for BANKCARD payment method only)*.  # noqa: E501

        :return: The preauth of this RecurringRequestRecurringData.  # noqa: E501
        :rtype: bool
        """
        return self._preauth

    @preauth.setter
    def preauth(self, preauth):
        """Sets the preauth of this RecurringRequestRecurringData.

        This parameter is allowed to be used only for first recurring payment. If set to `true`, the amount will not be captured but only blocked *(for BANKCARD payment method only)*.  # noqa: E501

        :param preauth: The preauth of this RecurringRequestRecurringData.  # noqa: E501
        :type: bool
        """

        self._preauth = preauth

    @property
    def retries(self):
        """Gets the retries of this RecurringRequestRecurringData.  # noqa: E501

        Number of daily basis retry attempts in case of payment has not been captured successfully, from 1 to 15 attempts can be specified.  # noqa: E501

        :return: The retries of this RecurringRequestRecurringData.  # noqa: E501
        :rtype: int
        """
        return self._retries

    @retries.setter
    def retries(self, retries):
        """Sets the retries of this RecurringRequestRecurringData.

        Number of daily basis retry attempts in case of payment has not been captured successfully, from 1 to 15 attempts can be specified.  # noqa: E501

        :param retries: The retries of this RecurringRequestRecurringData.  # noqa: E501
        :type: int
        """
        if retries is not None and retries > 15:  # noqa: E501
            raise ValueError("Invalid value for `retries`, must be a value less than or equal to `15`")  # noqa: E501
        if retries is not None and retries < 1:  # noqa: E501
            raise ValueError("Invalid value for `retries`, must be a value greater than or equal to `1`")  # noqa: E501

        self._retries = retries

    @property
    def subscription_start(self):
        """Gets the subscription_start of this RecurringRequestRecurringData.  # noqa: E501

        The date in yyyy-MM-dd format when subscription will actually become activated (grace period). Auth request will be created but Customer will be charged only when subscription start date comes. Leave it empty or specify the current date to activate subscription at once without any grace period applied.  # noqa: E501

        :return: The subscription_start of this RecurringRequestRecurringData.  # noqa: E501
        :rtype: datetime
        """
        return self._subscription_start

    @subscription_start.setter
    def subscription_start(self, subscription_start):
        """Sets the subscription_start of this RecurringRequestRecurringData.

        The date in yyyy-MM-dd format when subscription will actually become activated (grace period). Auth request will be created but Customer will be charged only when subscription start date comes. Leave it empty or specify the current date to activate subscription at once without any grace period applied.  # noqa: E501

        :param subscription_start: The subscription_start of this RecurringRequestRecurringData.  # noqa: E501
        :type: datetime
        """

        self._subscription_start = subscription_start

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if value is not None:
                    result[attr] = value
        if issubclass(RecurringRequestRecurringData, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RecurringRequestRecurringData):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    CardPay REST API

    Welcome to the CardPay REST API. The CardPay API uses HTTP verbs and a REST resources endpoint structure (see more info about REST). Request and response payloads are formatted as JSON. Merchant uses API to create payments, refunds, payouts or recurrings, check or update transaction status and get information about created transactions. In API authentication process based on OAuth 2.0 standard. For recent changes see changelog section.  # noqa: E501

    OpenAPI spec version: 3.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class PayoutRequestCard(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'expiration': 'str',
        'pan': 'str'
    }

    attribute_map = {
        'expiration': 'expiration',
        'pan': 'pan'
    }

    def __init__(self, expiration=None, pan=None):  # noqa: E501
        """PayoutRequestCard - a model defined in Swagger"""  # noqa: E501

        self._expiration = None
        self._pan = None
        self.discriminator = None

        if expiration is not None:
            self.expiration = expiration
        self.pan = pan

    @property
    def expiration(self):
        """Gets the expiration of this PayoutRequestCard.  # noqa: E501

        Customer's card expiration date. Format: `mm/yyyy`  # noqa: E501

        :return: The expiration of this PayoutRequestCard.  # noqa: E501
        :rtype: str
        """
        return self._expiration

    @expiration.setter
    def expiration(self, expiration):
        """Sets the expiration of this PayoutRequestCard.

        Customer's card expiration date. Format: `mm/yyyy`  # noqa: E501

        :param expiration: The expiration of this PayoutRequestCard.  # noqa: E501
        :type: str
        """
        if expiration is not None and not re.search(r'([0-9]{2}\/[0-9]{4})', expiration):  # noqa: E501
            raise ValueError(r"Invalid value for `expiration`, must be a follow pattern or equal to `/([0-9]{2}\/[0-9]{4})/`")  # noqa: E501

        self._expiration = expiration

    @property
    def pan(self):
        """Gets the pan of this PayoutRequestCard.  # noqa: E501

        Customer's card number (PAN). Any valid card number, may contain spaces. Required if `card_account.token` element isn't presented  # noqa: E501

        :return: The pan of this PayoutRequestCard.  # noqa: E501
        :rtype: str
        """
        return self._pan

    @pan.setter
    def pan(self, pan):
        """Sets the pan of this PayoutRequestCard.

        Customer's card number (PAN). Any valid card number, may contain spaces. Required if `card_account.token` element isn't presented  # noqa: E501

        :param pan: The pan of this PayoutRequestCard.  # noqa: E501
        :type: str
        """
        if pan is None:
            raise ValueError("Invalid value for `pan`, must not be `None`")  # noqa: E501
        if pan is not None and len(pan) > 19:
            raise ValueError("Invalid value for `pan`, length must be less than or equal to `19`")  # noqa: E501
        if pan is not None and len(pan) < 13:
            raise ValueError("Invalid value for `pan`, length must be greater than or equal to `13`")  # noqa: E501

        self._pan = pan

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if value is not None:
                    result[attr] = value
        if issubclass(PayoutRequestCard, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PayoutRequestCard):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    CardPay REST API

    Welcome to the CardPay REST API. The CardPay API uses HTTP verbs and a REST resources endpoint structure (see more info about REST). Request and response payloads are formatted as JSON. Merchant uses API to create payments, refunds, payouts or recurrings, check or update transaction status and get information about created transactions. In API authentication process based on OAuth 2.0 standard. For recent changes see changelog section.  # noqa: E501

    OpenAPI spec version: 3.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from cardpay.model.billing_address import BillingAddress  # noqa: F401,E501
from cardpay.model.payment_request_card import PaymentRequestCard  # noqa: F401,E501


class PaymentRequestCardAccount(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'billing_address': 'BillingAddress',
        'card': 'PaymentRequestCard',
        'token': 'str'
    }

    attribute_map = {
        'billing_address': 'billing_address',
        'card': 'card',
        'token': 'token'
    }

    def __init__(self, billing_address=None, card=None, token=None):  # noqa: E501
        """PaymentRequestCardAccount - a model defined in Swagger"""  # noqa: E501

        self._billing_address = None
        self._card = None
        self._token = None
        self.discriminator = None

        if billing_address is not None:
            self.billing_address = billing_address
        if card is not None:
            self.card = card
        if token is not None:
            self.token = token

    @property
    def billing_address(self):
        """Gets the billing_address of this PaymentRequestCardAccount.  # noqa: E501

        Billing Address  # noqa: E501

        :return: The billing_address of this PaymentRequestCardAccount.  # noqa: E501
        :rtype: BillingAddress
        """
        return self._billing_address

    @billing_address.setter
    def billing_address(self, billing_address):
        """Sets the billing_address of this PaymentRequestCardAccount.

        Billing Address  # noqa: E501

        :param billing_address: The billing_address of this PaymentRequestCardAccount.  # noqa: E501
        :type: BillingAddress
        """

        self._billing_address = billing_address

    @property
    def card(self):
        """Gets the card of this PaymentRequestCardAccount.  # noqa: E501

        Represents a payment card data. Card section shouldn't be present if element 'token' was presented. Shouldn't be used in Payment Page mode. For recurring: all card elements should presented only for first recurring payment.  # noqa: E501

        :return: The card of this PaymentRequestCardAccount.  # noqa: E501
        :rtype: PaymentRequestCard
        """
        return self._card

    @card.setter
    def card(self, card):
        """Sets the card of this PaymentRequestCardAccount.

        Represents a payment card data. Card section shouldn't be present if element 'token' was presented. Shouldn't be used in Payment Page mode. For recurring: all card elements should presented only for first recurring payment.  # noqa: E501

        :param card: The card of this PaymentRequestCardAccount.  # noqa: E501
        :type: PaymentRequestCard
        """

        self._card = card

    @property
    def token(self):
        """Gets the token of this PaymentRequestCardAccount.  # noqa: E501

        Card token value used instead of card information, except card.security_code (it's mandatory). For payment: see PaymentRequestPaymentData for token generation. For recurring: this attribute is valid only for first recurring payment. It isn't valid for continue recurring payments (with filing id), see RecurringRequestRecurringData for token generation.  # noqa: E501

        :return: The token of this PaymentRequestCardAccount.  # noqa: E501
        :rtype: str
        """
        return self._token

    @token.setter
    def token(self, token):
        """Sets the token of this PaymentRequestCardAccount.

        Card token value used instead of card information, except card.security_code (it's mandatory). For payment: see PaymentRequestPaymentData for token generation. For recurring: this attribute is valid only for first recurring payment. It isn't valid for continue recurring payments (with filing id), see RecurringRequestRecurringData for token generation.  # noqa: E501

        :param token: The token of this PaymentRequestCardAccount.  # noqa: E501
        :type: str
        """
        if token is not None and len(token) > 36:
            raise ValueError("Invalid value for `token`, length must be less than or equal to `36`")  # noqa: E501
        if token is not None and len(token) < 0:
            raise ValueError("Invalid value for `token`, length must be greater than or equal to `0`")  # noqa: E501

        self._token = token

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if value is not None:
                    result[attr] = value
        if issubclass(PaymentRequestCardAccount, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PaymentRequestCardAccount):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
